package App::btcindo;

our $DATE = '2017-11-24'; # DATE
our $VERSION = '0.010'; # VERSION

1;
# ABSTRACT: CLI for bitcoin.co.id (VIP)

__END__

=pod

=encoding UTF-8

=head1 NAME

App::btcindo - CLI for bitcoin.co.id (VIP)

=head1 VERSION

This document describes version 0.010 of App::btcindo (from Perl distribution App-btcindo), released on 2017-11-24.

=head1 SYNOPSIS

Please see included script L<btcindo>.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-btcindo>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-btcindo>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-btcindo>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<Finance::BTCIndo>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2017 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
